@@ -16,6 +16,11 @@ def caplog(caplog: LogCaptureFixture) -> None:
         None
     """
 
-    handler_id = logger.add(caplog.handler, format="{message}")
+    def filter_(record):
+        return record["level"].no >= caplog.handler.level
+
+    handler_id = logger.add(
+        caplog.handler, level=0, format="{message}", filter=filter_
+    )
     yield caplog
     logger.remove(handler_id)
